-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

newTalent{
	name = "Death's March",
	type = {"corruption/deaths-gifts", 1},
	points = 5,
	cooldown = 4,
	mode = "sustained",
	sustain_stamina = 50,
	tactical = { BUFF = 2 },
	activate = function(self, t)

		return {
			arm = self:addTemporaryValue("combat_armor", 7 + self:getTalentLevel(t) * self:getCon(10)),
			atk = self:addTemporaryValue("combat_dam", 4 + self:getTalentLevel(t) * self:getCon(10)),
			dam = self:addTemporaryValue("combat_atk", 4 + self:getTalentLevel(t) * self:getCon(10)),
			apr = self:addTemporaryValue("combat_apr", 3 + self:getTalentLevel(t) * self:getCon(10)),
			speed = self:addTemporaryValue("movement_speed", -.2),
		}
	end,
	deactivate = function(self, t, p)
		self:removeTemporaryValue("combat_physcrit", p.arm)
		self:removeTemporaryValue("combat_apr", p.apr)
		self:removeTemporaryValue("combat_atk", p.atk)
		self:removeTemporaryValue("combat_dam", p.dam)
		self:removeTemporaryValue("movement_speed", p.speed)
		return true
	end,
	info = function(self, t)
		return ([[Take slow steps while making a harsh and yeilding wall.  Increases armour by %d, attack and damage by %d , amour peircing by %d all while reducing movment speed by 20 percent.]]):format(7 + self:getTalentLevel(t) * self:getCon(10),4 + self:getTalentLevel(t) * self:getCon(10),4 + self:getTalentLevel(t) * self:getCon(10),3 + self:getTalentLevel(t) * self:getCon(10))
	end,
}

newTalent{
	name = "Shedding the Mortal Coil",
	type = {"corruption/deaths-gifts", 2},
	require = corrs_req2,
	points = 5,
	cooldown = 25,
	vim = 25,
	radius = function(self, t) return 1 + self:getTalentLevelRaw(t) end,
	target = function(self, t)
		return {type="ball", range=self:getTalentRange(t), radius=self:getTalentRadius(t), selffire=false, talent=t}
	end,
	action = function(self, t)
		local effs = {}
		-- Go through all spell effects
			for eff_id, p in pairs(self.tmp) do
				local e = self.tempeffect_def[eff_id]
				if e.status == "detrimental" and e.type == "magical" then
					effs[#effs+1] = {"effect", eff_id}
				end
			end

			local removed = 0
			local nb = 1+self:getTalentLevel(t)
			for i = 1, nb do
				if #effs == 0 then break end
				local eff = rng.tableRemove(effs)

				if eff[1] == "effect" then
					self:removeEffect(eff[2])
				end
				removed = removed + 1
			end

			game.level.map:particleEmitter(self.x, self.y, self:getTalentRadius(t), "shadow_zone")
			game:playSoundNear(self, "talents/fire")
		local dam = self:getTalentLevel(t) * 10 + removed*self:getTalentLevel(t)*5	
		local tg = self:getTalentTarget(t)
		self:project(tg, self.x, self.y, function(tx, ty)
			DamageType:get(DamageType.BLIGHT).projector(self, tx, ty, DamageType.BLIGHT, dam)
		end)
		return true
	end,
	info = function(self, t)
		local radius = self:getTalentRadius(t)
		return ([[purge %d negitive effects from your body and then deal %d blight damage plus %d for each effect in a %d radius.]]):format(1 + self:getTalentLevel(t), self:getTalentLevel(t) * 10,self:getTalentLevel(t)*5,radius)
	end,
}

newTalent{
	name = "Triumph of the Will",
	type = {"corruption/deaths-gifts", 3},
	require = corrs_req3,
	points = 5,
	mode = "passive",
	on_learn = function(self, t)
		self.combat_physresist = self.combat_physresist + 3
		self.combat_mentalresist = self.combat_mentalresist + 5
		self.combat_spellresist = self.combat_spellresist + 3
	end,
	on_unlearn = function(self, t)
		self.combat_physresist = self.combat_physresist - 3
		self.combat_mentalresist = self.combat_mentalresist - 5
		self.combat_spellresist = self.combat_spellresist - 3
	end,
	info = function(self, t)
		return ([[increase mental saves by %d and others by %d]]):
		format(5*self:getTalentLevelRaw(t) ,3*self:getTalentLevelRaw(t))
	end,
}

newTalent{
	name = "Death's Gifts",
	type = {"corruption/deaths-gifts", 4},
	require = corrs_req4,
	points = 5,
	getHealth = function(self, t) return 30 * self:getTalentLevelRaw(t) end,
	on_learn = function(self, t)
		self.max_life = self.max_life + 30
		self:addTemporaryValue("combat_spellpower", 3)
	end,
	on_unlearn = function(self, t)
		self.max_life = self.max_life - 30
		self:addTemporaryValue("combat_spellpower", -3)
	end,
	info = function(self, t)
		local health = t.getHealth(self, t)
		return ([[Increases your maximum life by %d and spell power by %d]]):
		format(health,self:getTalentLevelRaw(t)*3)
	end,
}
