-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

newTalent{
	name = "Death's Chill",
	type = {"corruption/deaths-presence", 1},
	points = 5,
	vim = 12,
	cooldown = function(self, t) return math.floor(20 - self:getTalentLevel(self.T_PRESENCE_OF_DEATH)*3) end,
	tactical = { ATTACKAREA = 2},
	direct_hit = true,
	requires_target = true,
	range = 0,
	radius = function(self, t) return 1 + self:getTalentLevelRaw(t) end,
	target = function(self, t)
		return {type="ball", range=self:getTalentRange(t), radius=self:getTalentRadius(t), selffire=false, talent=t}
	end,
	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 28, 200) + self:combatTalentSpellDamage(t, 28,self:getTalentLevel(self.T_PRESENCE_OF_DEATH)*30)  end,
	action = function(self, t)
		local dam = t.getDamage(self, t)
		local tg = self:getTalentTarget(t)
		self:project(tg, self.x, self.y, function(tx, ty)
			DamageType:get(DamageType.COLD).projector(self, tx, ty, DamageType.COLD, dam)
		end)
		game:playSoundNear(self, "talents/earth")
		return true
	end,
	info = function(self, t)
		local damage = t.getDamage(self, t)
		local radius = self:getTalentRadius(t)
		return ([[Dead have no need of heat to live.  You summon %0.2f Cold damage in a radius of %d.
		The damage will increase with the Magic stat]]):format(damDesc(self, DamageType.COLD, damage),radius)
	end,
}

newTalent{
	name = "Presence of Death",
	type = {"corruption/deaths-presence", 2},
	require = corrs_req2,
	mode = "passive",
	points = 5,
	info = function(self, t)
		return ([[You have gotten closer to Death and you can now summoning of its power to enhance your aruras (talents in this tree)]])
	end,
}

newTalent{
	name = "Death's Shadow",
	type = {"corruption/deaths-presence", 3},
	require = corrs_req3,
	points = 5,
	vim = 12,
	cooldown = function(self, t) return math.floor(30 - self:getTalentLevel(self.T_PRESENCE_OF_DEATH)*3) end,
	tactical = { ATTACKAREA = 2},
	direct_hit = true,
	requires_target = true,
	range = 0,
	radius = function(self, t) return 1 + self:getTalentLevelRaw(t)/2 end,
	getDuration = function(self, t) return 5 + self:combatSpellpower(0.05) + self:getTalentLevel(t) end,
	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 28, 100) + self:combatTalentSpellDamage(t, 28,self:getTalentLevel(self.T_PRESENCE_OF_DEATH)*40)  end,
	action = function(self, t)
		game.level.map:addEffect(self,
			self.x, self.y, t.getDuration(self, t),
			DamageType.DARKNESS, t.getDamage(self, t),
			t.radius(self,t),
			5, nil,
			engine.Entity.new{alpha=100, display='', color_br=200, color_bg=200, color_bb=200},
			function(e)
				e.x = e.src.x
				e.y = e.src.y
				return true
			end,
			false
		)
		game:playSoundNear(self, "talents/fire")
		return true
	end,
	info = function(self, t)
		local damage = t.getDamage(self, t)
		local radius = t.radius(self,t)
		local duration = t.getDuration(self, t)
		return ([[The shadow of death swirls around you dealing %0.2f Darkness damage over %d turns in a radius of %d
		The damage will increase with the Magic stat]]):format(damDesc(self, DamageType.DARKNESS, damage),duration,radius)
	end,
}

newTalent{
	name = "Death's Wages",
	type = {"corruption/deaths-presence", 4},
	require = corrs_req4,
	points = 5,
	vim = 12,
	cooldown = function(self, t) return math.floor(30 - self:getTalentLevel(self.T_PRESENCE_OF_DEATH)*3) end,
	tactical = { ATTACKAREA = 2},
	direct_hit = true,
	requires_target = true,
	range = 0,
	radius = function(self, t) return 1 + self:getTalentLevelRaw(t)/2 end,
	getDuration = function(self, t) return 5 + self:combatSpellpower(0.15) + self:getTalentLevel(t) end,
	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 28, 85) + self:combatTalentSpellDamage(t, 28,self:getTalentLevel(self.T_PRESENCE_OF_DEATH)*30)  end,
	action = function(self, t)
		game.level.map:addEffect(self,
			self.x, self.y, t.getDuration(self, t),
			DamageType.DRAINLIFE, t.getDamage(self, t),
			t.radius(self,t),
			5, nil,
			engine.Entity.new{alpha=100, display='', color_br=230, color_bg=255, color_bb=100},
			function(e)
				e.x = e.src.x
				e.y = e.src.y
				return true
			end,
			false
		)
		game:playSoundNear(self, "talents/fire")
		return true
	end,
	info = function(self, t)
		local damage = t.getDamage(self, t)
		local radius = t.radius(self,t)
		local duration = t.getDuration(self, t)
		return ([[waves of fell energy pulses around you dealing %0.2f Blight damage. over %d turns in a radius of %d.  You will heal 2/5 of the damage dealt 
		The damage will increase with the Magic stat]]):format(damDesc(self, DamageType.BLIGHT, damage),duration,radius)
	end,
}
