-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org
local function createFallenComrade(self, level, duration, target)
	return require("mod.class.NPC").new{
		type = "undead", subtype = "skeleton",
		name = "fallen comrade",
		desc = [[One of you allies from battles past summoned to aid you .]],
		display = 's', color=colors.BLACK,

		never_anger = true,
		summoner = self,
		summoner_gain_exp=true,
		summon_time = duration,
		faction = self.faction,
		size_category = 2,
		rank = 2,
		autolevel = "none",
		level_range = {level, level},
		exp_worth=0,

		max_life = resolvers.rngavg(15,20), life_rating = 8,
		energy = { mod=1 },
		stats = {
			str=10 + math.floor(level * 0.6),
			dex=15 + math.floor(level * 0.8),
			mag=5,
			wil=10 + math.floor(level * 0.2),
			cun=10 + math.floor(level * 0.2),
			con=10 + math.floor(level * 0.2),
		},
		combat_armor = 3 + level * 0.6, combat_def = 3 + level * 0.4,
		combat = {
			dam=15 + level * 8,
			atk=10 + 1.5 * level * 4,
			apr=10+ level * 2,
			dammod={dex=0.3, str=0.4}
		},
		on_melee_hit = { [DamageType.BLIGHT] = combatTalentSpellDamage(summoner.T_POWER_OF_THE_DEAD, getTalentLevel(summoner.T_POWER_OF_THE_DEAD)*6,100), },
		undead = 1,
		no_breath = 1,
		stone_immune = 1,
		confusion_immune = 1,
		fear_immune = 1,
		teleport_immune = 1,
		disease_immune = 1,
		poison_immune = 1,
		stun_immune = 1,
		blind_immune = 1,
		see_invisible = 80,
		resists = {[DamageType.LIGHT] = -40, [DamageType.DARKNESS] = 100, [DamageType.COLD] = 100, [DamageType.BLIGHT] = 100},

		ai = "fallen",
		ai_state = {
			summoner_range = 10,
			actor_range = 8,
			location_range = 4,
			target_time = 0,
			target_timeout = 1000,
			focus_on_target = true,
			shadow_wall = false,
			shadow_wall_time = 0,

			blindside_chance = 0,
			phasedoor_chance = 0,
			close_attack_spell_chance = 0,
			far_attack_spell_chance = 0,
			can_reform = false,
			dominate_chance = 0,

			feed_level = 0
		},
		ai_target = {
			actor=target,
			x = nil,
			y = nil
		},
		healSelf = function(self)
			return false
		end,

		
	}
end

newTalent{
	name = "Call the Dead",
	type = {"corruption/fallen-comrades", 1},
	points = 5,
	mode = "sustained",
	sustain_vim = 30,
	cooldown = 10,
	tactical = { BUFF = 5 },
	getLevel = function(self, t)
		return self.level --return math.max(1, self.level - 2 + self:getMag(4))
	end,
	getMaxComrades = function(self, t)
		return math.max(1, math.floor(self:getTalentLevel(t) * 0.55))
	end,
	activate = function(self, t)
		return {}
	end,
	deactivate = function(self, t, p)
		-- unsummon the shadows
		for _, e in pairs(game.level.entities) do
			if e.summoner and e.summoner == self and e.name == "fallen comrade" then
				e.summon_time = 0
			end
		end

		return true
	end,
	do_callFallen = function(self, t)
		if not self.fallen then
			self.fallen = {
				remainingCooldown = 0
			}
		end

		if game.zone.wilderness then return false end

		self.fallen.remainingCooldown = self.fallen.remainingCooldown - 1
		if self.fallen.remainingCooldown > 0 then return false end
		self.fallen.remainingCooldown = 10

		local fallenCount = 0
		for _, e in pairs(game.level.entities) do
			if e.summoner and e.summoner == self and e.name == "fallen comrade" then fallenCount = fallenCount + 1 end
		end

		if fallenCount >= t.getMaxComrades(self, t) then
			return false
		end

		-- Find space
		local x, y = util.findFreeGrid(self.x, self.y, 8, true, {[Map.ACTOR]=true})
		if not x then
			return false
		end

		-- use hate
		if self.vim < 25 then
			-- not enough hate..just wait for another try
			game.logPlayer(self, "You vim is too low to call another shadow!", deflectDamage)
			return false
		end
		self:incVim(-25)

		level = t.getLevel(self, t)
		local fallen = createFallenComrade(self, level, 1000, nil)

		fallen:resolve()
		fallen:resolve(nil, true)
		fallen:forceLevelup(level)
		game.zone:addEntity(game.level, fallen, "actor", x, y)
		--shadow:feed()
		game.level.map:particleEmitter(x, y, 1, "teleport_in")

		game:playSoundNear(self, "talents/spell_generic")
		return true
	end,
	removeAllShadows = function(self, t)
		for _, e in pairs(game.level.entities) do
			if e.summoner and e.summoner == self and e.name == "fallen comrade" then
				e:die()
			end
		end
	end,
	info = function(self, t)
		local maxFallen = t.getMaxComrades(self, t)
		local level = t.getLevel(self, t)
		return ([[Call upon fallen comrades from battles in the past.  While active you have a chance to summon %d fallen comrades who are %d level.  Each summon cost 25 vim]]):format(maxFallen, level)
	end,
}

newTalent{
	name = "Death Frenzy",
	type = {"corruption/fallen-comrades", 2},
	require = corrs_req2,
	points = 5,
	cooldown = 25,
	vim = 25,

	action = function(self, t)
		for _, e in pairs(game.level.entities) do
			if e.summoner and e.summoner == self and e.name == "fallen comrade" then
				--buff skeleton
				e:setEffect(e.EFF_DEATH_FRENZY, 5+self:getTalentLevel(t)*2, {damage=(10 + self:getMag() / 4)*self:getTalentLevel(t),speed = 10*self:getTalentLevel(t)},false)
			end
		end
		self:setEffect(self.EFF_DEATH_FRENZY, 5+self:getTalentLevel(t)*2, {damage=(10 + self:getMag() / 8)*self:getTalentLevel(t),speed = 5*self:getTalentLevel(t)},false)
		return true
	end,
	info = function(self, t)
		return ([[increases your comrades speed by %d and adds %d darkness damage to their blows for %d turns.  You will also have your speed increased by %d and %d darkness damage added to.]]):format(10*self:getTalentLevel(t),(10 + self:getMag() / 4)*self:getTalentLevel(t),5+self:getTalentLevel(t)*2,5*self:getTalentLevel(t),(10 + self:getMag() / 8)*self:getTalentLevel(t))
	end,
}

newTalent{
	name = "Power of the Dead",
	type = {"corruption/fallen-comrades", 3},
	require = corrs_req3,
	mode = "passive",
	points = 5,
	info = function(self, t)
		return ([[Fallen Comrades now deal %d blight damage when hit in melee]]):format(combatTalentSpellDamage(summoner.T_POWER_OF_THE_DEAD, getTalentLevel(summoner.T_POWER_OF_THE_DEAD)*6,100))
	end,
}

newTalent{
	name = "Fate of the Fallen",
	type = {"corruption/fallen-comrades", 4},
	require = corrs_req4,
	points = 5,
	cooldown = 200,
	mode = "sustained",
	sustain_vim = 50,
	absorb = function(self, t, p,incoming)
		for _, e in pairs(game.level.entities) do
			if e.summoner and e.summoner == self and e.name == "fallen comrade" then
				game.logPlayer(self, "Your fallen comrade absorbs the damage!")
				e:takeHit(incoming, e)
				return 0
			end
		end
		return incoming 
		
		
	end,
	activate = function(self, t)
		return true
	end,
	deactivate = function(self, t, p)
		return true
	end,
	info = function(self, t)
		return ([[Your comrades will make the ultimate sacrifice for you.  While this talent is active there is a %d chance that one of the fallen will take the blow]]):format(self:getTalentLevelRaw(t)*20)
	end,
}
