-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

newTalent{
	name = "Lifestealer",
	type = {"corruption/warrior-of-death", 1},
	points = 5,
	cooldown = 4,
	vim = 10,
	range = 1,
	tactical = { ATTACK = 2 },
	requires_target = true,
	action = function(self, t)
		local tg = {type="hit", range=self:getTalentRange(t)}
		local x, y, target = self:getTarget(tg)
		if not x or not y or not target then return nil end
		if math.floor(core.fov.distance(self.x, self.y, x, y)) > 1 then return nil end
		self:attackTarget(target, DamageType.DRAINLIFE, 1.2 + self:getTalentLevel(t) / 6, true)
		return true
	end,
	info = function(self, t)
		return ([[You call upon the mighty power of death in your next attack, doing %d%% weapon damage as blight damage. and healing 2/5 of the damage dealt]]):format(100 * (1.2 + self:getTalentLevel(t) / 6))
	end,
}

newTalent{
	name = "Reaper's Sweep",
	type = {"corruption/warrior-of-death", 2},
	require = corrs_req2,
	points = 5,
	random_ego = "attack",
	cooldown = 8,
	stamina = 30,
	requires_target = true,
	tactical = { ATTACKAREA = 2 },
	action = function(self, t)

		local tg = {type="hit", range=self:getTalentRange(t)}
		local x, y, target = self:getTarget(tg)
		if not x or not y or not target then return nil end
		if math.floor(core.fov.distance(self.x, self.y, x, y)) > 1 then return nil end

		local dir = util.getDir(x, y, self.x, self.y)
		local lx, ly = util.coordAddDir(self.x, self.y, dir_sides[dir].left)
		local rx, ry = util.coordAddDir(self.x, self.y, dir_sides[dir].right)
		local lt, rt = game.level.map(lx, ly, Map.ACTOR), game.level.map(rx, ry, Map.ACTOR)

		local hit
		hit = self:attackTarget(target, nil, self:combatTalentWeaponDamage(t, 1, 1.7), true)

		if lt then
			hit = self:attackTarget(lt, nil, self:combatTalentWeaponDamage(t, 1, 1.7), true)
		end

		if rt then
			hit = self:attackTarget(rt, nil, self:combatTalentWeaponDamage(t, 1, 1.7), true)

		end
		print(x,y,target)
		print(lx,ly,lt)
		print(rx,ry,rt)

		return true
	end,
	info = function(self, t)
		return ([[You are mighty but alone so you must sweep aside your foes.  Attack your foes in a frontal arc doing %d%% weapon damage ]]):
		format(100 * self:combatTalentWeaponDamage(t, 1, 1.7))
	end,
}

newTalent{
	name = "Feast of Darkness",
	type = {"corruption/warrior-of-death", 3},
	require = corrs_req3,
	points = 5,
	action = function(self, t)
		self:setEffect(self.EFF_LEACHING_WEAPON, 5+self:getTalentLevel(t)*2, {damage=(10 + self:getMag() / 4)*self:getTalentLevel(t)},false)
		return true
	end,
	info = function(self, t)
		return ([[Your weapons are infused with the hunger of Death.  Because you are the one that does the hard work you get a cut of the energy.  Adds %d darkness damage to your blows that heal 2/5 of the damage and restores 1/5 of the damage as vim for %d turns]]):
		format((10 + self:getMag() / 4)*self:getTalentLevel(t),5+self:getTalentLevel(t)*2)
	end,
}

newTalent{
	name = "Nether Blade",
	type = {"corruption/warrior-of-death", 4},
	require = corrs_req4,
	mode = "sustained",
	points = 5,
	sustain_stamina = 50,
	sustain_vim = 40,
	cooldown = 15,
	tactical = { ATTACKAREA = 1, DISABLE = 2, ESCAPE = 2 },
	activate = function(self, t)
		game:playSoundNear(self, "talents/slime")
		local ret = {
			particle = self:addParticles(Particles.new("darkness_shield", 1))
		}
		return ret
	end,
	deactivate = function(self, t, p)
		self:removeParticles(p.particle)
		return true
	end,
	info = function(self, t)
		return ([[you summon a Nether blade that snuffs out life of everthing it touchs.  This comes at a cost though and you will lose %d life whenever the blades asorbs a life.  your melee blows deal 500%% darkness damage and any creature that falls below 60%% life will be killed intantly]]):format(self.max_life*.1/self:getTalentLevelRaw(t))
	end,
}
